import React from "react"
import { graphql, useStaticQuery } from "gatsby"

import { Carousel } from "@onegeo-suite/gatsby-theme-onegeo"

interface Props {
    className?: string
    delay?: number
}

const Funders = (props: Props) => {
    const { className = "", delay = 2000 } = props

    const dataDirectus = useStaticQuery(graphql`
        query getFunders {
            directus {
                partners(
                    filter: {
                        status: { _eq: "published" }
                        type: { _eq: "funder" }
                    }
                ) {
                    id
                    name
                    url
                    logo {
                        id
                        imageFile {
                            childImageSharp {
                                gatsbyImageData
                            }
                            name
                            publicURL
                        }
                    }
                }
            }
        }
    `)

    const funders = dataDirectus.directus.partners
    if (!funders) return null

    const dataImage = funders.map((partner: any) => {
        return { src: partner.logo.imageFile }
    })

    return (
        <div className={`${className}`}>
            <Carousel images={dataImage} isLogo={true} delay={delay} />
        </div>
    )
}

export default Funders
