import React from "react"
import { Swiper, SwiperSlide } from "swiper/react"
import { Navigation, A11y } from "swiper"

// Import Swiper styles
import "swiper/css"
import "swiper/css/navigation"
import "swiper/css/pagination"
import "swiper/css/scrollbar"
import { graphql, useStaticQuery } from "gatsby"
import { Logo } from "@onegeo-suite/gatsby-theme-onegeo"
import "../../css/marquee.css"

const Marquee = () => {
    const dataDirectus = useStaticQuery(graphql`
        query getLogo {
            directus {
                partners(filter: { status: { _eq: "published" } }) {
                    logo {
                        id
                        imageFile {
                            childImageSharp {
                                gatsbyImageData
                            }
                            name
                            publicURL
                        }
                    }
                }
            }
        }
    `)
    const partners = dataDirectus.directus.partners

    const url = "#"
    return (
        <>
            <Swiper
                slidesPerView={1}
                spaceBetween={1}
                navigation
                loop={true}
                slidesPerGroup={1}
                loopFillGroupWithBlank={true}
                breakpoints={{
                    "@0.00": {
                        slidesPerView: 1,
                        spaceBetween: 4,
                    },
                    "@0.75": {
                        slidesPerView: 2,
                        spaceBetween: 6,
                    },
                    "@1.00": {
                        slidesPerView: 3,
                        spaceBetween: 8,
                    },
                    "@1.50": {
                        slidesPerView: 4,
                        spaceBetween: 10,
                    },
                }}
                modules={[Navigation, A11y]}
                className="mySwiper"
            >
                {partners.map((item: any, key: number) => (
                    <SwiperSlide
                        className="slide flex items-center justify-center"
                        key={key}
                    >
                        <div className="slide-content flex w-20 justify-center">
                            <div className="user-image">
                                <Logo
                                    image={item.logo.imageFile}
                                    url={url}
                                    className="user-photo w-16"
                                    title=""
                                />
                            </div>
                        </div>
                    </SwiperSlide>
                ))}
            </Swiper>
        </>
    )
}

export default Marquee
