import React from "react"

import OMSBaseLayer from "./OMSBaseLayer"
import WMTSBaseLayer from "./WMTSBaseLayer"

interface Props {
    layers: any
}

const MapsBaseLayer = (props: Props) => {
    const { layers } = props

    return (
        <>
            {
                // BACKGROUNDS
                layers
                    .filter(
                        (layer) =>
                            layer.title?.toLowerCase() === "fond cartographique"
                    )
                    .map((layer) => {
                        return layer.childs.map((childLayer, key) => {
                            switch (childLayer.type?.toLowerCase()) {
                                case "osm":
                                    return (
                                        <OMSBaseLayer
                                            key={key}
                                            checked={childLayer.visible}
                                            name={childLayer.title}
                                        />
                                    )
                                case "wmts":
                                    const oUrl = new URL(childLayer.url)

                                    return (
                                        <WMTSBaseLayer
                                            key={key}
                                            checked={childLayer.visible}
                                            name={childLayer.title}
                                            opacity={childLayer.opacity}
                                            url={{
                                                hostname: `${oUrl.origin}${oUrl.pathname}`,
                                                layername: childLayer.layername,
                                            }}
                                        />
                                    )
                            }
                        })
                    })
            }
        </>
    )
}

export default MapsBaseLayer
