import React from "react"
import { LayersControl, TileLayer } from "react-leaflet"

interface Props {
    checked: boolean
    name: string
    opacity: number
    url: {
        layername: string
        format?: string
        style?: string
        hostname: string
    }
}

const WMTSBaseLayer = (props: Props) => {
    const {
        checked,
        name,
        opacity,
        url: { layername, format = "image/jpeg", style = "normal", hostname },
    } = props

    const url = `${hostname}?service=WMTS&request=GetTile&version=1.0.0&tilematrixset=PM&tilematrix={z}&tilecol={x}&tilerow={y}&layer=${layername}&format=${format}&style=${style}`

    return (
        <LayersControl.BaseLayer checked={checked} name={name}>
            <TileLayer url={url} tileSize={256} opacity={opacity} />
        </LayersControl.BaseLayer>
    )
}

export default WMTSBaseLayer
